:mod:`pymunk.autogeometry` Module
---------------------------------

.. container:: custom-index
    
    .. raw:: html
    
        <script type="text/javascript" src='_static/pymunk.js'></script>
    
.. automodule:: pymunk.autogeometry
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:
    :special-members: __init__
